"""migrate from experiments to jobs

Revision ID: 5d7c6a1edaa7
Revises: 5a915f45eb6f
Create Date: 2021-01-18 16:27:10.036716

"""
import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "5d7c6a1edaa7"
down_revision = "5a915f45eb6f"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "jobs",
        sa.Column("name", sa.String(length=255), nullable=False),
        sa.Column("uuid", sa.String(length=255), nullable=False),
        sa.Column("pipeline_uuid", sa.String(length=255), nullable=False),
        sa.Column("project_uuid", sa.String(length=255), nullable=False),
        sa.Column("pipeline_name", sa.String(length=255), nullable=False),
        sa.Column("pipeline_path", sa.String(length=255), nullable=False),
        sa.Column(
            "created",
            sa.DateTime(),
            server_default=sa.text("timezone('utc', now())"),
            nullable=False,
        ),
        sa.Column("strategy_json", sa.Text(), nullable=False),
        sa.Column("draft", sa.Boolean(), nullable=True),
        sa.ForeignKeyConstraint(
            ["project_uuid"],
            ["project.uuid"],
            name=op.f("fk_jobs_project_uuid_project"),
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("uuid", name=op.f("pk_jobs")),
        sa.UniqueConstraint("uuid", name=op.f("uq_jobs_uuid")),
    )
    op.add_column(
        "pipelineruns", sa.Column("job", sa.String(length=255), nullable=True)
    )
    op.create_foreign_key(
        op.f("fk_pipelineruns_job_jobs"),
        "pipelineruns",
        "jobs",
        ["job"],
        ["uuid"],
        ondelete="CASCADE",
    )

    op.drop_constraint(
        "fk_pipelineruns_experiment_experiments", "pipelineruns", type_="foreignkey"
    )
    op.drop_column("pipelineruns", "experiment")
    op.drop_table("experiments")
    # ### end Alembic commands ###


def downgrade():
    # Note: downgrade has not been checked for correctness.

    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "pipelineruns",
        sa.Column(
            "experiment", sa.VARCHAR(length=255), autoincrement=False, nullable=True
        ),
    )
    op.drop_constraint(
        op.f("fk_pipelineruns_job_jobs"), "pipelineruns", type_="foreignkey"
    )
    op.create_foreign_key(
        "fk_pipelineruns_experiment_experiments",
        "pipelineruns",
        "experiments",
        ["experiment"],
        ["uuid"],
        ondelete="CASCADE",
    )
    op.drop_constraint(op.f("uq_pipelineruns_uuid"), "pipelineruns", type_="unique")
    op.drop_column("pipelineruns", "job")
    op.create_table(
        "experiments",
        sa.Column("name", sa.VARCHAR(length=255), autoincrement=False, nullable=False),
        sa.Column("uuid", sa.VARCHAR(length=255), autoincrement=False, nullable=False),
        sa.Column(
            "pipeline_uuid", sa.VARCHAR(length=255), autoincrement=False, nullable=False
        ),
        sa.Column(
            "project_uuid", sa.VARCHAR(length=255), autoincrement=False, nullable=False
        ),
        sa.Column(
            "pipeline_name", sa.VARCHAR(length=255), autoincrement=False, nullable=False
        ),
        sa.Column(
            "pipeline_path", sa.VARCHAR(length=255), autoincrement=False, nullable=False
        ),
        sa.Column(
            "created",
            postgresql.TIMESTAMP(),
            server_default=sa.text("timezone('utc'::text, now())"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column("strategy_json", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("draft", sa.BOOLEAN(), autoincrement=False, nullable=True),
        sa.ForeignKeyConstraint(
            ["project_uuid"],
            ["project.uuid"],
            name="fk_experiments_project_uuid_project",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("uuid", name="pk_experiments"),
    )
    op.drop_table("jobs")
    # ### end Alembic commands ###
